<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryRef" :inline="true" v-show="showSearch" label-position="left" label-width="50px">
      <el-row :gutter="20">
        <el-col :span="6">
          <el-form-item label="料号" prop="itemNumber">
            <el-input
              v-model="queryParams.itemNumber"
              placeholder="请输入料号"
              clearable
              @keyup.enter="handleQuery"
            />
          </el-form-item>
        </el-col>
        <!-- <el-col :span="18" style="text-align: right;">
          <el-form-item>
              <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
              <el-button icon="Refresh" @click="resetQuery">重置</el-button>
            </el-form-item>
        </el-col> -->
      </el-row>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <right-toolbar v-model:showSearch="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <HxlhTable
        style="width: 100%"
        :columns="columns"
        :data="professionalFixedCycleManagementList"
        :loading="loading"
        :height="height"
        :page="page"
        @changePageNo="changePageNo"
        @changePageSize="changePageSize"
    >
    </HxlhTable>

    <!-- 添加或修改专业固定周期管理对话框 -->
    <el-dialog :title="title" v-model="open" width="500px" append-to-body>
      <el-form ref="professionalFixedCycleManagementRef" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="料号" prop="itemNumber">
          <el-input v-model="form.itemNumber" placeholder="请输入料号" />
        </el-form-item>
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitForm">确 定</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>
      </template>
    </el-dialog>
  </div>
</template>

<script setup name="ProfessionalFixedCycleManagement">
import { listProfessionalFixedCycleManagement, getProfessionalFixedCycleManagement, delProfessionalFixedCycleManagement, addProfessionalFixedCycleManagement, updateProfessionalFixedCycleManagement } from "@/api/basicData/professionalFixedCycleManagement/professionalFixedCycleManagement";
import HxlhTable from '@/components/HxlhTable';
import axios from 'axios';
import { listAll_plant } from "@/api/basicData/plant";

const { proxy } = getCurrentInstance();

const professionalFixedCycleManagementList = ref([]);
const open = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const ids = ref([]);
const single = ref(true);
const multiple = ref(true);
const title = ref("");
const height = ref(document.documentElement.clientHeight - 230 + "px;")
const queryPlants = ref({status: 1});
const plantList = ref([]);

const data = reactive({
  form: {},
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    itemNumber: null,
  },
  rules: {
  }
});

// 表格配置 
const columns = ref([
  { type: 'seq', title: '序号', width: 60 },
  {
    title: '料号',
    field: 'itemNumber',
  },
  {
    title: '专业描述',
    field: 'professionalDescription',
  },
  {
    title: '专业',
    field: 'professional',
  },
  {
    title: '专业固定周期',
    field: 'professionalFixedCycle',
  },
  {
    title: '集成日期',
    field: 'integrationDate',
  },
  {
    title: '适用工厂',
    field: 'applicableFactories',
    formatter: (({ cellValue, row, column }) => {
      if (cellValue) {
        for(let i=0;i<plantList.value.length;i++){
          if(cellValue===plantList.value[i].plantCode){
            return plantList.value[i].plantName
          }
        }
      }
      return '';
    })
  },
]);

// 分页属性
const page = ref({
  total: 0,
  current: 1,
  size: 10
});

const { queryParams, form, rules } = toRefs(data);

/** 查询专业固定周期管理列表 */
function getList() {
  loading.value = true;
  axios.all([
      /** 查询工厂列表 */
      listAll_plant(queryPlants.value),
      listProfessionalFixedCycleManagement(queryParams.value)
    ])
    .then(axios.spread((response1, response2) => {
      plantList.value = response1.data;
      professionalFixedCycleManagementList.value = response2.rows;
      page.value.total = response2.total;
      loading.value = false;
    }))
    .catch(error => {
      console.error('请求出错:', error);
    });
}

// 取消按钮
function cancel() {
  open.value = false;
  reset();
}

// 表单重置
function reset() {
  form.value = {
    id: null,
    itemNumber: null,
    professionalDescription: null,
    professional: null,
    professionalFixedCycle: null,
    integrationDate: null,
    applicableFactories: null,
    createBy: null,
    createTime: null,
    updateBy: null,
    updateTime: null
  };
  proxy.resetForm("professionalFixedCycleManagementRef");
}

/** 搜索按钮操作 */
function handleQuery() {
  page.value.current = 1;
  queryParams.value.pageNum = 1;
  getList();
}

/** 重置按钮操作 */
function resetQuery() {
  proxy.resetForm("queryRef");
  handleQuery();
}

// 多选框选中数据
function handleSelectionChange(selection) {
  ids.value = selection.map(item => item.id);
  single.value = selection.length != 1;
  multiple.value = !selection.length;
}

/** 新增按钮操作 */
function handleAdd() {
  reset();
  open.value = true;
  title.value = "添加专业固定周期管理";
}

/** 修改按钮操作 */
function handleUpdate(row) {
  reset();
  const _id = row.id || ids.value
  getProfessionalFixedCycleManagement(_id).then(response => {
    form.value = response.data;
    open.value = true;
    title.value = "修改专业固定周期管理";
  });
}

/** 提交按钮 */
function submitForm() {
  proxy.$refs["professionalFixedCycleManagementRef"].validate(valid => {
    if (valid) {
      if (form.value.id != null) {
        updateProfessionalFixedCycleManagement(form.value).then(response => {
          proxy.$modal.msgSuccess("修改成功");
          open.value = false;
          getList();
        });
      } else {
        addProfessionalFixedCycleManagement(form.value).then(response => {
          proxy.$modal.msgSuccess("新增成功");
          open.value = false;
          getList();
        });
      }
    }
  });
}

/** 删除按钮操作 */
function handleDelete(row) {
  const _ids = row.id || ids.value;
  proxy.$modal.confirm('是否确认删除专业固定周期管理编号为"' + _ids + '"的数据项？').then(function() {
    return delProfessionalFixedCycleManagement(_ids);
  }).then(() => {
    getList();
    proxy.$modal.msgSuccess("删除成功");
  }).catch(() => {});
}

/** 导出按钮操作 */
function handleExport() {
  proxy.download('basicData/professionalFixedCycleManagement/export', {
    ...queryParams.value
  }, `professionalFixedCycleManagement_${new Date().getTime()}.xlsx`)
}

function changePageNo(currentPage) {
  page.value.current = currentPage;
  queryParams.value.pageNum = currentPage;
  getList();
}

function changePageSize(pageSize) {
  page.value.current = 1;
  queryParams.value.pageNum = 1;
  queryParams.value.pageSize = pageSize;
  getList();
}

getList();
</script>
